starcluster.commands.terminate.CmdTerminate

Package starcluster :: Package commands :: Module terminate :: Class CmdTerminate |
[hide private]
[frames] | no frames]

# Class CmdTerminate

source code

    terminate [options] <cluster_tag> ...

    Terminate a running or stopped cluster

    Example:

        $ starcluster terminate mycluster

    This will terminate a currently running or stopped cluster tagged
    "mycluster".

    All nodes will be terminated, all spot requests (if any) will be
    cancelled, and the cluster's security group will be removed. If the
    cluster uses EBS-backed nodes then each node's root volume will be
    deleted.  If the cluster uses "cluster compute" instance types the
    cluster's placement group will also be removed.

Instance Methods | [hide private]
addopts(self, parser) | source code
terminate_cluster(self, cluster_name) | source code
terminate_manually(self, cluster_name) | source code
execute(self, args) | source code
Inherited from `completers.ClusterCompleter` (private): `_completer` Inherited from `completers.Completer` (private): `_prep_for_completion` Inherited from `base.CmdBase`: `cancel_command`, `catch_ctrl_c`, `warn_experimental` Inherited from `base.CmdBase` (private): `_positive_int` Inherited from `optcomplete.CmdComplete`: `autocomplete` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| names = ``[``'``terminate``'``]``
Inherited from `completers.Completer` (private): `_cfg` Inherited from `base.CmdBase`: `gopts`, `gparser`, `opts`, `parser`, `subcmds_map` Inherited from `base.CmdBase` (private): `_cm`, `_ec2`, `_nm`, `_s3`

Properties | [hide private]
Inherited from `completers.Completer`: `completer` Inherited from `base.CmdBase`: `cfg`, `cluster_manager`, `cm`, `comp_words`, `ec2`, `goptions_dict`, `log`, `nm`, `node_manager`, `options_dict`, `s3`, `specified_options_dict` Inherited from `object`: `__class__`

Method Details | [hide private]

### addopts(self, parser) | source code
Overrides: base.CmdBase.addopts